Seantis Agencies
================

A directory of people for (government) agencies.

Build Status
------------

.. image:: https://travis-ci.org/seantis/seantis.agencies.png
  :target: https://travis-ci.org/seantis/seantis.agencies
  :alt: Build Status

Coverage
--------

.. image:: https://coveralls.io/repos/seantis/seantis.agencies/badge.png?branch=master
  :target: https://coveralls.io/r/seantis/seantis.agencies?branch=master
  :alt: Project Coverage

Latests PyPI Release
--------------------
.. image:: https://pypip.in/v/seantis.agencies/badge.png
  :target: https://crate.io/packages/seantis.agencies
  :alt: Latest PyPI Release

License
-------
seantis.agencies is released under GPLv2
